@@ -12,6 +12,9 @@ test_that("returns the correct linting", {
 
   expect_lint("\"'blah'\"", NULL, single_quotes_linter)
 
+  expect_lint("'\"'", NULL, single_quotes_linter)
+  expect_lint("'\"blah\"'", NULL, single_quotes_linter)
+
   expect_lint("'blah'",
     rex("Only use double-quotes."),
     single_quotes_linter)
